package org.jeecg.ctop.finance.policy.service.impl;

import cn.com.ctop.common.module.mapper.SysUserMapper;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import org.jeecg.common.system.entity.SysUser;
import org.jeecg.ctop.finance.policy.entity.CwjsPolicyInfo;
import org.jeecg.ctop.finance.policy.mapper.CwjsPolicyInfoMapper;
import org.jeecg.ctop.finance.policy.service.ICwjsPolicyInfoService;
import org.jeecg.ctop.finance.policy.utils.Check;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import javax.annotation.Resource;
import java.util.*;

/**
 * 政策信息表
 * @author jeecg-boot
 * 2021-07-27
 * @version V1.0
 */
@Service
public class CwjsPolicyInfoServiceImpl extends ServiceImpl<CwjsPolicyInfoMapper, CwjsPolicyInfo> implements ICwjsPolicyInfoService {
    @Resource
    CwjsPolicyInfoMapper policyInfoMapper;

    @Override
    public List<CwjsPolicyInfo> queryPageList(CwjsPolicyInfo policyInfo){

        List<CwjsPolicyInfo> policyInfoList = policyInfoMapper.selectPolicyInfos(policyInfo);
        List<CwjsPolicyInfo> result = new ArrayList<>();
        //1.过滤所有已通过审核的政策到结果表中
        policyInfoList.forEach(policy->{
            if(policy.getApprovedStatus() == 3){
                JSONArray policyProductName = new JSONArray();
                policyProductName.add(policy.getProductName());
                policy.setPolicyProductName(policyProductName);
                result.add(policy);
            }
        });
        policyInfoList.removeAll(result);
        Map<Integer,CwjsPolicyInfo> map = new HashMap<>();
        //2.未通过审核的政策需要通过政策id来进行聚合，把产品名称放到同一个列表里
        policyInfoList.forEach(policy->{
            if(map.containsKey(policy.getId())){
                map.get(policy.getId()).getPolicyProductName().add(policy.getProductName());
            }else{
                JSONArray policyProductName = new JSONArray();
                policyProductName.add(policy.getProductName());
                policy.setPolicyProductName(policyProductName);
                map.put(policy.getId(),policy);
            }
        });
        //3.遍历聚合完成后的map，每一个key对应一条不通过的政策的数据，放入到结果集返回
        Set<Integer> keys = map.keySet();
        for(Integer key : keys){
            result.add(map.get(key));
        }


        return result;
    }

    @Override
    public List<JSONObject> getAllSale(){
        return policyInfoMapper.getAllSale();
    }

    @Override
    public List<JSONObject> getAllSaleAndMeidaManager(){
        return policyInfoMapper.getAllSaleAndMeidaManager();
    }

    /**
     * 查询 所有 运营
     * @return
     */
    @Override
    public List<Map<String,Object>> getAllOperationUser(){
        return policyInfoMapper.getAllOperationUser();
    }

    @Override
    public List<JSONObject> getAllSaleByUserId(String userId){
        return policyInfoMapper.getAllSaleByUserId(userId);
    }


    @Autowired
    private SysUserMapper userMapper;
    @Override
    public List<JSONObject> getAllSubordinate2(String userId){
        List<SysUser> allList = userMapper.selectAllUser();
        List<SysUser> mulUserList = treeCategoryData(allList, userId);
        List<JSONObject> users = new ArrayList<>();
        mulUserList.forEach(mulUser -> {
            JSONObject jo = new JSONObject();
            jo.put("userId",mulUser.getId());
            jo.put("userName",mulUser.getRealname());
            users.add(jo);
        });
        return users;
    }


    @Override
    public List<String> getAllSubordinate(String userId){
        List<SysUser> allList = userMapper.selectAllUser();
        List<SysUser> mulUserList = treeCategoryData(allList, userId);
        List<String> userIds = new ArrayList<>();
        userIds.add(userId);
        mulUserList.forEach(mulUser -> userIds.add(mulUser.getId()));
        return userIds;
    }
    public List<SysUser> treeCategoryData(List<SysUser> allList, String leaderId) {
        List<SysUser> mapList = new ArrayList<>();
        for (SysUser vo : allList) {
            if (leaderId.equals(vo.getLeaderId())){
                mapList.add(vo);
                mapList.addAll(treeCategoryData(allList,vo.getId()));
            }
        }
        return mapList;

    }

    @Override
    public boolean isExistCwjsPolicyInfo(CwjsPolicyInfo policyInfo){
        CwjsPolicyInfo cwjsPolicyInfoEntity = new CwjsPolicyInfo();
        cwjsPolicyInfoEntity.setAdvertiserName(policyInfo.getAdvertiserName());
        cwjsPolicyInfoEntity.setProductName(policyInfo.getProductName());
        cwjsPolicyInfoEntity.setMediaType(policyInfo.getMediaType());
        cwjsPolicyInfoEntity.setCreateUserId(policyInfo.getCreateUserId());
        cwjsPolicyInfoEntity.setPolicyStartDate(policyInfo.getPolicyStartDate());
        cwjsPolicyInfoEntity.setPolicyEndDate(policyInfo.getPolicyEndDate());
        List<CwjsPolicyInfo> cwjsPolicyInfos = policyInfoMapper.selectPolicyInfos(policyInfo);
        if(Check.isNull(cwjsPolicyInfos)){
            return false;
        }else {
            return true;
        }
    }

    @Override
    public void updatePolicyInfoById(CwjsPolicyInfo policyInfo){
        policyInfoMapper.updatePolicyInfoById(policyInfo);
    }
}
