package org.jeecg.ctop.finance.settlement.controller;

import cn.com.ctop.common.module.service.ISysUserService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.entity.SysUser;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.ctop.finance.policy.utils.Check;
import org.jeecg.ctop.finance.settlement.entity.pojo.CtopCwjsSettlementFileInfo;
import org.jeecg.ctop.finance.settlement.entity.vo.SettlementFileParamsVo;
import org.jeecg.ctop.finance.settlement.service.ISettlementFileInfoService;
import org.jeecg.modules.ctop.service.IMaterialReportOverViewService;
import org.jeecg.modules.system.service.ISysRoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;


/**
 * Administrator
 * 2021/7/28
 **/

@Slf4j
@RestController
@RequestMapping("/settLementFileController")
public class SettlementFileController {
    @Autowired
    private ISettlementFileInfoService settlementFileInfoService;
    @Autowired
    private ISysRoleService sysRoleService;
    @Autowired
    private IMaterialReportOverViewService materialReportOverViewService;

    @ApiOperation(value="结算单-结算单列表查询", notes="结算单-结算单列表查询")
    @GetMapping(value = "/getSettlementSheetList")
    public Result<PageInfo<Map<String,String>>> getSettlementSheetList(SettlementFileParamsVo paramsVo,
                                                                       @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                                                       @RequestParam(name="pageSize", defaultValue="10") Integer pageSize) {
        //查询用户角色
        String roleCode = sysRoleService.getRoleCodeByUserId(paramsVo.getCreateUserId());

        //管理员 || 财务
        if ("admin".equals(roleCode) || "finance".equals(roleCode)){
            paramsVo.setOperatorUserIds(null);
            paramsVo.setSaleUserIds(null);
         //运营经理
        }else if ("kuaishou_operations_director".equals(roleCode) || //快手运营总监
                "toutiao_operations_manager".equals(roleCode) || // 头条运营经理
                "externalOperationManager".equals(roleCode) || //外部运营经理
                "genera_manager_of_operations".equals(roleCode) || //运营总经理
                "toutiao_operations_director".equals(roleCode) || //头条运营总监
                "kuaishou_operations_manager".equals(roleCode)) //快手运营经理
         {
            //查询所有包含自己的下级
            Set<String> operatorUserIds= materialReportOverViewService.recursiveQuerySubordinate(paramsVo.getCreateUserId());
            paramsVo.setOperatorUserIds(operatorUserIds);
        //运营助理 || 运营专员
        }else if("operationAssistant".equals(roleCode) || "operator".equals(roleCode)){
            paramsVo.setOperatorUserIds(new HashSet<String>(){{
                add(paramsVo.getCreateUserId());
            }});
        //销售总监 || 销售支持经理
        }else if("saleDirector".equals(roleCode) || "salesSupportManager".equals(roleCode)){
            Set<String> saleUserIds= materialReportOverViewService.recursiveQuerySubordinate(paramsVo.getCreateUserId());
            paramsVo.setSaleUserIds(saleUserIds);
            //外部销售 || 销售AM || 销售助理 || 销售
        }else if ("externalSale".equals(roleCode) || "saleAm".equals(roleCode) || "saleAssistant".equals(roleCode) || "sale".equals(roleCode)){
            paramsVo.setSaleUserIds(new HashSet<String>(){{
                add(paramsVo.getCreateUserId());
            }});
        }
       return settlementFileInfoService.getSettlementSheetList(paramsVo,pageNo,pageSize);
    }


    @ApiOperation(value="结算单-删除", notes="结算单-删除")
    @GetMapping(value = "/deleteSettlementFile")
    public Result deleteSettlementFile(SettlementFileParamsVo paramsVo) {
        return settlementFileInfoService.deleteSettlementFile(paramsVo);
    }

    @ApiOperation(value="结算单-账户截图上传", notes="结算单-账户截图上传")
    @PostMapping(value = "/insertAccountImages")
    public Result insertAccountImages(@RequestBody CtopCwjsSettlementFileInfo settlementFileInfo) {
        if (Check.isNull(settlementFileInfo.getSettlementList())){
            return Result.errorMsg("账户截图不能为空！");
        }
        return settlementFileInfoService.insertAccountImages(settlementFileInfo);
    }

    @ApiOperation(value="结算单-查询账户数量以及图片数量", notes="结算单-查询账户数量以及图片数量")
    @PostMapping(value = "/getAccountNumAndImgNum")
    public Result getAccountNumAndImgNum(@RequestBody SettlementFileParamsVo paramsVo) {
        LoginUser loginUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        SysUser user = userService.getById(loginUser.getId());
        return settlementFileInfoService.getAccountNumAndImgNum(paramsVo,user);
    }
    @Autowired
    private ISysUserService userService;

}